@@ -6,13 +6,14 @@ Module: taz
 Trivial Azure API
 
 Subpackages:
-    - taz[blob]
+    - taz[storage]
     - taz[dev]
     - taz[dls]
     - taz[aci]
     - taz[auth]
 
-to include in requirements.txt use notation: taz[blob,dls] for example
+to include in requirements.txt use notation: taz[storage,dls] for example
+keyvault support is not optionnal
 
 Submodules:
     - taz.keyvault
@@ -21,6 +22,7 @@ Submodules:
     - taz.aci
     - taz.blob (use Azure storage SDK v12)
     - taz.dls
+    - taz.table
 
 Copyright (C) 2018-2020, Christophe Fauchard
 """
