@@ -325,12 +325,15 @@ class SimpleContainerGroup:
         datas_group_logs = self.__str__()
         datas_container_logs = self.list_logs()
 
-        if self.last_finish_time:
-            name_group_log = "taz.aci.group.{}.{}.log".format(
-                self.last_finish_time, self.name
+        if not self.last_finish_time == "None":
+            name_group_log = "{}.{}.taz.aci.group.{}.log".format(
+                self.last_start_time, self.last_finish_time, self.name
             )
-            name_container_log = "taz.aci.container.{}.{}.{}.log".format(
-                self.last_finish_time, self.name, self.container_name,
+            name_container_log = "{}.{}.taz.aci.container.{}.{}.log".format(
+                self.last_start_time,
+                self.last_finish_time,
+                self.name,
+                self.container_name,
             )
             blob_group_logs = Blob(
                 container,
@@ -390,6 +393,7 @@ class SimpleContainerGroup:
                 start_time = str(instance.instance_view.current_state.start_time)
                 finish_time = str(instance.instance_view.current_state.finish_time)
                 self.last_finish_time = finish_time
+                self.last_start_time = start_time
                 exit_code = instance.instance_view.current_state.exit_code
                 detail_status = instance.instance_view.current_state.detail_status
                 memory = instance.resources.requests.memory_in_gb
