@@ -2,10 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Taz library: blobs operations
-
-Blob Storage Resources
-
+Taz library: containers and blobs
 """
 import urllib
 from azure.core.exceptions import ResourceExistsError
@@ -22,49 +19,18 @@ from datetime import datetime, timedelta
 import pandas as pd
 import gzip
 
+from taz.storage_account import StorageAccount
 from taz.exception import BlobAthenticationFailedException
 
 
-class StorageAccount:
-    def __init__(self, name, connection_string, key=None):
-        """Define Storage Account Object
-
-        only connection_string is used, key is only stored in object
-
-        :param name: storage account name
-        :type name: str
-        :param connection_string: storage account connection string
-        :type connection_string: str
-        :param key: key (not used), defaults to None
-        :type key: str, optional
-        """
-        self.name = name
-        self.key = key
-        self.connection_string = connection_string
-
-        self.blob_service_client = BlobServiceClient.from_connection_string(
-            self.connection_string
-        )
-
-    def list_containers(self, prefix=None):
-        """ list storage account containers
-
-        Returns:
-            - azure.storage.blob.models.Container List: list of container, Container class attributes:
-                - name
-                - metadata
-                - properties
-        """
-        return self.blob_service_client.list_containers(name_starts_with=prefix)
-
-
 class Container:
     def __init__(self, storage_account, name):
-        """ define Container object 
+        """Blob Container
 
-        Args:
-            storage_account (TYPE): Description
-            name (TYPE): Description
+        :param storage_account: storage account
+        :type storage_account: taz.storage_account.StorageAccount
+        :param name: container name
+        :type name: str
         """
         self.storage_account = storage_account
         self.name = name
@@ -79,12 +45,37 @@ class Container:
             )
 
     def get_properties(self):
+        """get container properties
+
+        :return: container properties
+        :rtype: azure.storage.blob.ContainerProperties
+        """
         return self.client.get_container_properties()
 
     def delete(self):
-        return self.storage_account.blob_service_client.delete_container(self.name)
+        """delete Container
+
+        :return: self obj
+        :rtype: taz.blob.Container
+        """
+        self.storage_account.blob_service_client.delete_container(self.name)
+        return self
 
     def list_blobs(self, prefix=None):
+        """list blobs in container
+
+        :param prefix: prefix of blobs to list, defaults to None
+        :type prefix: str, optional
+        :return: list of blobs properties
+        :rtype: Iterable of azure.storage.blob.BlobProperties
+            BloProperties fields:
+            - name
+            - container
+            - metadata
+            - size
+            - last_modified
+            (see Azure documentation for further details) 
+        """
         return self.client.list_blobs(name_starts_with=prefix)
 
 
@@ -141,13 +132,20 @@ class Blob:
         else:
             raise (BlobAthenticationFailedException(self.name))
 
-    def get_sas_token(self):
+    def get_sas_token(
+        self, expiry=datetime.utcnow() + timedelta(hours=1), permission_string="racwd",
+    ):
         """generate sas token for blob
 
+        :param expiry: token expiration date, defaults to datetime.utcnow()+timedelta(hours=1)
+        :type expiry: datetime.datetime, optional
+        :param permission_string: blob access permissions, defaults "racwd" (read, add, create, write, delete)
+        :type permission_string: str, optional
         :return: sas token
         :rtype: str
         """
-        permission = BlobSasPermissions.from_string("racwd")
+
+        permission = BlobSasPermissions.from_string(permission_string)
 
         self.sas_token = generate_blob_sas(
             self.storage_account.name,
@@ -155,37 +153,46 @@ class Blob:
             self.name,
             account_key=self.storage_account.key,
             permission=permission,
-            expiry=datetime.utcnow() + timedelta(hours=1),
+            expiry=expiry,
         )
         return self.sas_token
 
-    def get_url(self):
+    def get_url(
+        self, expiry=datetime.utcnow() + timedelta(hours=1), permission_string="racwd",
+    ):
         """get url with sas token to download blob
 
+        :param expiry: token expiration date, defaults to datetime.utcnow()+timedelta(hours=1)
+        :type expiry: datetime.datetime, optional
+        :param permission: blob access permissions, defaults "racwd" (read, add, create, write, delete)
+        :type permission: BlobSasPermissions, optional
         :return: blob url
         :rtype: str
         """
-        return "{}?{}".format(self.client.url, self.get_sas_token())
+        return "{}?{}".format(
+            self.client.url,
+            self.get_sas_token(expiry=expiry, permission_string=permission_string),
+        )
 
     def read(self):
         """read datas from blob
         
-        :return: data read
-        :rtype: binary string
+        datas neads to be decoded, example for utf8 text:
+        myblob.read().decode("utf8")
+
+        :return: binary data read
+        :rtype: bytes
         """
         return self.client.download_blob().readall()
 
     def read_csv(self, **kargs):
         """read CSV file from Blob
 
-        Args:
-            - path (string): remote csv file path to read
-            - **kargs: arguments array passed to pandas.read_csv
-
-        Returns:
-            - pandas.DataFrame: DataFrame filled with read datas
+        :param **kargs: all pandas.Dataframe.read_csv() params
+        :type kargs: *
+        :return: DataFrame filled with read datas
+        :rtype:  pandas.DataFrame
         """
-
         return pd.read_csv(self.get_url(), **kargs)
 
     def gzip_write(self, data, overwrite=True):
@@ -199,7 +206,17 @@ class Blob:
         return self.write(gzip.compress(data, compresslevel=9), overwrite=overwrite)
 
     def write(self, data, overwrite=True):
-        return self.client.upload_blob(data, overwrite=overwrite)
+        """write data to blob
+
+        :param data: data
+        :type data: bytes
+        :param overwrite: overwrite blob if existing, defaults to True
+        :type overwrite: bool, optional
+        :return: self obj
+        :rtype: taz.blob.Blob
+        """
+        self.client.upload_blob(data, overwrite=overwrite)
+        return self
 
     def upload(self, path, overwrite=True):
         """upload file to blob
@@ -211,26 +228,41 @@ class Blob:
         """
         with open(path, "rb") as data:
             self.write(data, overwrite=True)
+        return self
 
     def download(self, path):
         """download blob to local file
 
         :param path: local path to write blob
         :type path: str
+        :return: self obj
+        :rtype: taz.blob.Blob
         """
         with open(path, "wb") as data:
             data.write(self.read())
+        return self
 
     def delete(self):
         """delete blob
+
+        :return: self obj
+        :rtype: taz.blob.Blob
         """
         self.client.delete_blob()
+        return self
 
     def add_metadata(self, metadata):
-        old_metadata = self.get_metadata()
-        metadata.update(old_metadata)
-        self.set_metadata(metadata)
-        return self.get_metadata()
+        """merge metadata to existing
+
+        :param metadata: metadata to merge
+        :type metadata: dict
+        :return: self obj
+        :rtype: taz.blob.Blob
+        """
+        new_metadata = self.get_metadata()
+        new_metadata.update(metadata)
+        self.set_metadata(new_metadata)
+        return self
 
     def set_metadata(self, metadata: dict):
         """replace blob metadata
@@ -239,9 +271,14 @@ class Blob:
         :type metadata: dict
         """
         self.client.set_blob_metadata(metadata)
-        return self.get_metadata()
+        return self
 
     def get_metadata(self):
+        """get blob metadata
+
+        :return: metadatas
+        :rtype: dict
+        """
         return self.get_properties().metadata
 
     def get_properties(self):
