@@ -6,8 +6,9 @@ sys.path.insert(0, "../")
 
 from tests.config import *
 
-dicts_name = [ "keyvault", "auth", "blob", "acr", "aci", "dls", "dls_glob" ]
-safe_values = [ "client_secret", "storage_connection_string", "storage_key", "sas_key"]
+dicts_name = ["keyvault", "auth", "blob", "acr", "aci", "dls", "dls_glob", "tables"]
+safe_values = ["client_secret", "storage_connection_string", "storage_key", "sas_key"]
+
 
 def displaydict(dict_name):
     dict = eval(dict_name)
@@ -15,9 +16,9 @@ def displaydict(dict_name):
     for key, value in dict.items():
         if key in safe_values:
             value = "<secured string>"
-        print(f"    {key}: \"{value}\"")
+        print(f'    {key}: "{value}"')
     print("}")
 
+
 for dict_name in dicts_name:
     displaydict(dict_name)
-
